@@ -68,6 +68,11 @@ def mock(path: str) -> tuple[Any, int]:
 
     log.info(f"Matched `{path}` to endpoint: {endpoint}")
 
+    active_responses = [response for response in endpoint.responses if response.is_active]
+
+    if not active_responses:
+        return "No Mock Responses configured or active for this endpoint", 501
+
     response_rules = [
         (
             response,
@@ -79,7 +84,7 @@ def mock(path: str) -> tuple[Any, int]:
                 for rule in response.rules
             ],
         )
-        for response in endpoint.responses
+        for response in active_responses
     ]
 
     if request.is_json:
